{% extends 'django_spire/item/item.html' %}

{% block item_title_col %}d-none{% endblock %}

{% block item_row_content %}
    <a class="col-5" href="{% url 'django_spire:help_desk:page:detail' pk=ticket.pk %}">
        {% include 'django_spire/element/attribute_element.html' with attribute_title=ticket attribute_value=ticket.description|truncatechars:50 %}
    </a>
    <div class="col-2">
        {% include 'django_spire/element/attribute_element.html' with attribute_value=ticket.created_by.get_full_name attribute_title='Created By' %}
    </div>
    <div class="col-2">
        {% include 'django_spire/element/attribute_element.html' with attribute_value=ticket.created_datetime|date:'M d, Y' attribute_title='Created At' %}
    </div>
    <div class="col-3 text-center">
        {% include 'django_spire/help_desk/element/ticket_purpose_badge.html' %}
        {% include 'django_spire/help_desk/element/ticket_priority_badge.html' %}
        {% include 'django_spire/help_desk/element/ticket_status_badge.html' %}
    </div>
{% endblock %}